@@ -69,7 +69,7 @@ def call_meta_initializer_if_needed(cls: Type[W]):
     """
     Calls the Meta initializer when the inner :class:`Meta` is sub-classed.
     """
-    cls_name = cls.__name__
+    cls_name = get_class_name(cls)
 
     if cls_name in _META_INITIALIZER:
         _META_INITIALIZER[cls_name](cls)
@@ -100,8 +100,8 @@ def get_class_name(class_or_instance) -> str:
 
 def get_outer_class_name(inner_cls, default=None, raise_=True):
     """
-    Attempt to return the name of the outer (enclosing) class, given
-    a reference to the inner class.
+    Attempt to return the fully qualified name of the outer (enclosing) class,
+    given a reference to the inner class.
 
     If any errors occur - such as when `inner_cls` is not a real inner
     class - then an error will be raised if `raise_` is true, and if not
@@ -109,13 +109,19 @@ def get_outer_class_name(inner_cls, default=None, raise_=True):
 
     """
     try:
-        return inner_cls.__qualname__.rsplit('.', 2)[-2]
+        name = get_class_name(inner_cls).rsplit('.', 1)[-2]
+        # This is mainly for our test cases, where we nest the class
+        # definition in the test func. Either way, it's not a valid class.
+        assert not name.endswith('<locals>')
 
-    except IndexError:
+    except (IndexError, AssertionError):
         if raise_:
             raise
         return default
 
+    else:
+        return name
+
 
 def get_class(obj):
     """Get the class for an object `obj`"""
